@@ -3,29 +3,40 @@
 #' Calculating confidence bands for impulse response via moving block bootstrap
 #'
 #' @param x SVAR object of class "svars"
-#' @param b.length Length of each block
-#' @param horizon Time horizon of impulse response functions
-#' @param nboot Number of bootstrap iterations
-#' @param nc Number of processor cores (Not available on windows machines)
+#' @param b.length Integer. Length of each block
+#' @param n.ahead Integer specifying the steps
+#' @param nboot Integer. Number of bootstrap iterations
+#' @param nc Integer. Number of processor cores (Not available on windows machines)
 #' @param dd Object of class 'indepTestDist'. A simulated independent sample of the same size as the data.
 #' If not supplied, it will be calculated by the function
 #' @param signrest A list with vectors containing 1 and -1, e.g. c(1,-1,1), indicating a sign pattern of specific shocks to be tested
 #' with the help of the bootstrap samples.
-#' @param itermax Maximum number of iterations for DEoptim
-#' @param steptol Tolerance for steps without improvement for DEoptim
-#' @param iter2 Number of iterations for the second optimization
+#' @param itermax Integer. Maximum number of iterations for DEoptim
+#' @param steptol Numeric. Tolerance for steps without improvement for DEoptim
+#' @param iter2 Integer. Number of iterations for the second optimization
 #' @return A list of class "sboot" with elements
+#' \item{true}{Point estimate of impulse response functions}
+#' \item{bootstrap}{List of length "nboot" holding bootstrap impulse response functions}
+#' \item{SE}{Bootstraped standard errors of estimated covariance decomposition
+#' (only if "x" has method "Cramer von-Mises", or "Distance covariances")}
+#' \item{nboot}{Number of bootstrap iterations}
+#' \item{b_length}{Length of each block}
+#' \item{point_estimate}{Point estimate of covariance decomposition}
 #' \item{boot_mean}{Mean of bootstrapped covariance decompositions}
-#' \item{sign_complete}{Frequency of bootstrapped covariance decompositions which conform the complete predetermined sign pattern. If signrest=NULL,
+#' \item{signrest}{Evaluated sign pattern}
+#' \item{sign_complete}{Frequency of appearance of the complete sign pattern in all bootstrapped covariance decompositions}
+#' \item{sign_part}{Frequency of bootstrapped covariance decompositions which conform the complete predetermined sign pattern. If signrest=NULL,
 #'  the frequency of bootstrapped covariance decompositions that hold the same sign pattern as the point estimate is provided.}
-#' \item{sign_part}{Frequency of single shocks in all bootstrapped covariance decompositions which accord to a specific predetermined sign pattern
-#'  }
-#'
-#' @seealso \code{\link{id.cvm}}, \code{\link{id.dc}}, \code{\link{id.ngml}}, \code{\link{id.cv} or \code{\link{id.st}}
+#' \item{sign_part}{Frequency of single shocks in all bootstrapped covariance decompositions which accord to a specific predetermined sign pattern}
+#' \item{cov_bs}{Covariance matrix of bootstrapped parameter in impact relations matrix}
+#' \item{method}{Used bootstrap method}
 #'
 #' @references Brueggemann, R., Jentsch, C., and Trenkler, C. (2016). Inference in VARs with conditional heteroskedasticity of unknown form. Journal of Econometrics 191, 69-85.\cr
 #'   Herwartz, H., 2017. Hodges Lehmann detection of structural shocks -
-#'        An analysis of macroeconomic dynamics in the Euro Area, Oxford Bulletin of Economics and Statistics
+#'        An analysis of macroeconomic dynamics in the Euro Area, Oxford Bulletin of Economics and Statistics.
+#'
+#' @seealso \code{\link{id.cvm}}, \code{\link{id.dc}}, \code{\link{id.ngml}}, \code{\link{id.cv}} or \code{\link{id.st}}
+#'
 #' @examples
 #' \donttest{
 #' # data contains quarterly observations from 1965Q1 to 2008Q3
@@ -40,7 +51,7 @@
 #' # impulse response analysis with confidence bands
 #' # Checking how often theory based impact relations appear
 #' signrest <- list(demand = c(1,1,1), supply = c(-1,1,1), money = c(-1,-1,1))
-#' bb <- mb.boot(x1, b.length = 15, nboot = 500, horizon = 30, nc = 1, signrest = signrest)
+#' bb <- mb.boot(x1, b.length = 15, nboot = 500, n.ahead = 30, nc = 1, signrest = signrest)
 #' summary(bb)
 #' plot(bb, lowerq = 0.16, upperq = 0.84)
 #' }
@@ -49,27 +60,15 @@
 #' @export
 
 
-mb.boot <- function(x, b.length = 15, horizon, nboot, nc = 1, dd = NULL, signrest = NULL,  itermax = 300, steptol = 200, iter2 = 50){
+mb.boot <- function(x, b.length = 15, n.ahead = 20, nboot = 500, nc = 1, dd = NULL, signrest = NULL,  itermax = 300, steptol = 200, iter2 = 50){
   # x: vars object
   # B: estimated covariance matrix from true data set
-  # horizon: Time horizon for Irf
+  # n.ahead: Time steps for Irf
   # nboot: number of bootstrap replications
   if(x$method == "Cramer-von Mises distance" & is.null(dd)){
     dd <- copula::indepTestSim(x$n, x$K, verbose=F)
   }
 
-  # function to create Z matrix
-  y_lag_cr <- function(y, lag_length){
-    # create matrix that stores the lags
-    y_lag <- matrix(NA, dim(y)[1],dim(y)[2]*lag_length)
-    for (i in 1:lag_length) {
-      y_lag[(1+i):dim(y)[1],((i*NCOL(y)-NCOL(y))+1):(i*NCOL(y))] <- y[1:(dim(y)[1]-i),(1:NCOL(y))]
-    }
-    # drop first observation
-    y_lag <- as.matrix(y_lag[-(1:lag_length),])
-    out <- list(lags = y_lag)
-  }
-
   sqrt.f <- function(Pstar, Sigma_u_star){
     yy <- suppressMessages(sqrtm(Sigma_u_hat_old))%*%solve(suppressMessages(sqrtm(Sigma_u_star)))%*%Pstar
     return(yy)
@@ -116,11 +115,11 @@ mb.boot <- function(x, b.length = 15, horizon, nboot, nc = 1, dd = NULL, signres
   }
 
   for(i in 1:nboot){
-    epsilon.star <- matrix(0, b.length*ceiling(N), ncol(u))
+    epsilon.star <- matrix(0, b.length*(ceiling(N)+1), ncol(u))
     epsilon.star <- list()
     # stacking randomly selected blocks at each other
-    for(kk in 1:ceiling(N)){
-      epsilon.star[[kk]] <- blocks[,,floor(runif(1, 1, obs-b.length+2))]
+    for(kk in 1:(ceiling(N)+1)){
+      epsilon.star[[kk]] <- blocks[,,floor(runif(1, 1, obs - b.length+2))]
     }
     epsilon.star <- do.call('rbind', epsilon.star)
 
@@ -177,7 +176,7 @@ mb.boot <- function(x, b.length = 15, horizon, nboot, nc = 1, dd = NULL, signres
     # class(varb) <- 'var.boot'
 
     if(x$method == "Non-Gaussian maximum likelihood"){
-      temp <- id.ngml_boot(varb, stage3 = x$stage3)
+      temp <- id.ngml_boot(varb, stage3 = x$stage3, restriction_matrix = x$restriction_matrix)
     }else if(x$method == "Changes in Volatility"){
       temp <- tryCatch(id.cv_boot(varb, SB = x$SB, restriction_matrix = x$restriction_matrix),
                        error = function(e) NULL)
@@ -206,7 +205,7 @@ mb.boot <- function(x, b.length = 15, horizon, nboot, nc = 1, dd = NULL, signres
       Pstar <- Pstar1%*%frobP$perm
       temp$B <- Pstar
 
-      ip <- imrf(temp, horizon = horizon)
+      ip <- irf(temp, n.ahead = n.ahead)
       return(list(ip, Pstar))
     }else{
       return(NA)
@@ -303,7 +302,7 @@ mb.boot <- function(x, b.length = 15, horizon, nboot, nc = 1, dd = NULL, signres
   }
 
   ## Impulse response of actual model
-  ip <- imrf(x, horizon = horizon)
+  ip <- irf(x, n.ahead = n.ahead)
 
   result <- list(true = ip,
                  bootstrap = ipb,
