@@ -1,15 +1,15 @@
-identifyVolatility = function(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restriction_matrix = restriction_matrix,
+identifyVolatility = function(x, SB, Tob = Tob, u = u, k = k, y = y, restriction_matrix = restriction_matrix,
                                     Sigma_hat1 = Sigma_hat1, Sigma_hat2 = Sigma_hat2, p = p, TB = TB, SBcharacter,
                                      max.iter, crit = crit, yOut = yOut, type = type){
 
 
   if(!is.null(restriction_matrix)){
-    B <- t(chol((1/Tob)* crossprod(u_t)))
+    B <- t(chol((1/Tob)* crossprod(u)))
     naElements <- is.na(restriction_matrix)
     B <- B[naElements]
     restrictions <- length(restriction_matrix[!is.na(restriction_matrix)])
   }else{
-    B <- t(chol((1/Tob)* crossprod(u_t)))
+    B <- t(chol((1/Tob)* crossprod(u)))
     B <- c(B)
   }
   Lambda <- rep(1, k)
@@ -32,18 +32,6 @@ identifyVolatility = function(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restric
   }
   ll <- MLE$minimum
 
-  # estimating again with GLS to obatin a more precise estimation
-    y_lag_cr <- function(y, lag_length){
-      # create matrix that stores the lags
-      y_lag <- matrix(NA, dim(y)[1],dim(y)[2]*lag_length)
-      for (i in 1:lag_length) {
-        y_lag[(1+i):dim(y)[1],((i*NCOL(y)-NCOL(y))+1):(i*NCOL(y))] <- y[1:(dim(y)[1]-i),(1:NCOL(y))]
-      }
-      # drop first observation
-      y_lag <- as.matrix(y_lag[-(1:lag_length),])
-      out <- list(lags = y_lag)
-    }
-
     yl <- t(y_lag_cr(t(y), p)$lags)
     yret <- y
     y <- y[,-c(1:p)]
@@ -114,21 +102,21 @@ identifyVolatility = function(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restric
     GLS_hat <- GLS1%*%GLS2
 
     term1 <- apply(Z_t, 2, resid.gls, k = k, GLS_hat = GLS_hat)
-    u_tgls <- t(y) - t(term1)
+    ugls <- t(y) - t(term1)
 
-    resid1gls <- u_tgls[1:TB-1,]
-    resid2gls <- u_tgls[TB:Tob,]
+    resid1gls <- ugls[1:TB-1,]
+    resid2gls <- ugls[TB:Tob,]
     Sigma_hat1gls <- (crossprod(resid1gls)) / (TB-1)
     Sigma_hat2gls <- (crossprod(resid2gls)) / (Tob-TB+1)
 
     # Determine starting values for B and Lambda
     if(!is.null(restriction_matrix)){
-      B <- t(chol((1/Tob)* crossprod(u_t)))
+      B <- t(chol((1/Tob)* crossprod(u)))
       naElements <- is.na(restriction_matrix)
       B <- B[naElements]
       restrictions <- length(restriction_matrix[!is.na(restriction_matrix)])
     }else{
-      B <- t(chol((1/Tob)* crossprod(u_t)))
+      B <- t(chol((1/Tob)* crossprod(u)))
       B <- c(B)
     }
     Lambda <- rep(1, k)
@@ -196,6 +184,10 @@ identifyVolatility = function(x, SB, Tob = Tob, u_t = u_t, k = k, y = y, restric
 
   # Testing the estimated SVAR for identification by menas of wald statistic
   wald <- wald.test(Lambda_hat, HESS, restrictions)
+ rownames(B_hat) <- colnames(u)
+ rownames(Lambda_hat) <- colnames(u)
+ rownames(Lambda.SE) <- colnames(u)
+ rownames(B.SE) <- colnames(u)
 
 result <- list(
   Lambda = Lambda_hat,    # estimated Lambda matrix (unconditional heteroscedasticity)
